
#line 2 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 119
#define YY_END_OF_BUFFER 120
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[267] =
    {   0,
        0,    0,    0,    0,    0,    0,  115,  115,    0,    0,
        0,    0,  120,  101,  100,   99,  101,   80,   18,   87,
      101,   92,  101,   83,   84,   90,   88,   85,   89,  101,
       91,   74,   86,   19,   76,   93,   77,  101,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   98,   95,   96,  101,  107,  106,  107,  107,
      114,  113,  114,  114,  115,  116,  118,  117,  118,  110,
      109,   99,   79,   75,   81,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   74,   78,   94,   98,   97,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,

       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   82,  106,    0,    0,  113,    0,    0,  115,
      117,  110,  109,    0,    0,    0,    0,    0,    0,    0,
        1,    0,    0,    0,    0,    0,    0,   29,   26,   70,
       57,   58,   55,   73,   60,   56,   59,   61,   62,   47,
       51,   41,   50,   31,   32,   33,   68,   64,   66,   28,
       67,   63,   65,   54,   53,   20,   21,   22,   69,   42,
       27,   36,   38,   37,   39,   72,   71,   49,   30,   48,
       52,   40,   23,   24,   25,   46,   44,   34,   45,   35,

       43,    0,    0,  102,    0,  111,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    8,   14,    0,    0,
        0,    0,    0,    0,    0,   16,    0,   10,    2,    3,
        0,    0,    0,    0,    0,    0,   17,   15,  103,  104,
        0,    0,    0,    0,    4,    9,    0,    0,    0,    0,
        6,  105,  112,    0,    0,   11,   12,    0,    0,    0,
        7,    5,   13,    0,  108,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    9,   10,    1,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   20,   21,   22,
       23,   24,   25,    1,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   47,   48,   49,   50,   36,
        1,    1,    1,    1,   51,    1,   52,   53,   54,   55,

       56,   57,   58,   59,   60,   61,   36,   62,   63,   64,
       65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
       75,   36,    1,   76,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[77] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    1,    4,    5,
        1,    1,    1,    1,    1,    4,    4,    4,    4,    4,
        4,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    4,    4,    4,    4,    4,    4,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    1
    } ;

static const flex_int16_t yy_base[276] =
    {   0,
        0,    0,   74,   76,   78,   80,  601,  600,   82,   84,
      588,  587,  603,  608,  608,  608,  599,  578,  608,  608,
        0,  608,  590,  608,  608,  608,  608,  608,  608,   71,
      608,  580,  608,  608,  608,  575,  608,  574,   74,  125,
       84,   72,   70,  576,   69,   79,  129,   92,  131,  134,
      142,  150,  166,  575,  574,  517,  608,  608,  589,  170,
      608,  608,  588,  171,    0,  608,  608,  608,  587,    0,
      191,  608,  608,    0,  608,   65,  100,  174,  193,  126,
      122,  138,  153,  174,  570,  608,  608,  568,  608,  205,
      214,  209,  224,  203,  217,  229,  228,  235,  236,  247,

      233,  246,  263,  257,  278,  245,  265,  290,  283,  268,
      298,  303,  315,  311,  302,  329,  346,  310,  338,  294,
      350,  352,  608,  608,  352,  346,  608,  215,  351,    0,
      608,    0,  570,  322,  345,  361,  362,  363,  367,  356,
      608,  377,  381,  378,  373,  371,  382,  566,  565,  564,
      563,  562,  561,  560,  559,  558,  557,  556,  553,  547,
      517,  516,  514,  512,  511,  510,  507,  505,  504,  501,
      499,  495,  488,  477,  471,  460,  391,  378,  373,  343,
      327,  325,  295,  284,  272,  262,  253,  241,  240,  231,
      202,  199,  156,  155,  149,  141,  140,  117,  100,   87,

       86,  393,  397,  608,  399,  608,  400,  400,  399,  398,
      403,  409,  406,  403,  421,  403,  608,  608,  402,  412,
      413,  419,  417,  427,  419,  608,  425,  608,  608,  608,
      442,  433,  444,  449,  441,  444,  608,  608,  608,  608,
      454,  455,  462,  460,  608,  608,  453,  454,  467,  455,
      608,  608,  608,  472,  473,  608,  608,  473,  478,  467,
      608,  608,  608,  473,  608,  608,  538,  543,  548,  553,
      558,   92,  560,  565,  570
    } ;

static const flex_int16_t yy_def[276] =
    {   0,
      266,    1,  267,  267,  268,  268,  269,  269,  270,  270,
      271,  271,  266,  266,  266,  266,  266,  266,  266,  266,
      272,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  274,  266,  266,  266,  266,  275,
      266,  266,  266,  272,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  273,  266,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,

      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  266,  266,  266,  266,  266,  266,  266,  274,
      266,  275,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,

      273,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,    0,  266,  266,  266,  266,
      266,  266,  266,  266,  266
    } ;

static const flex_int16_t yy_nxt[685] =
    {   0,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   44,   44,   45,   46,   44,   47,   44,   48,   49,
       50,   44,   51,   52,   53,   44,   44,   44,   54,   55,
       14,   39,   40,   41,   42,   43,   44,   44,   44,   45,
       46,   47,   44,   48,   49,   50,   44,   51,   52,   53,
       44,   44,   44,   54,   55,   56,   58,   59,   58,   59,
       62,   63,   62,   63,   68,   69,   68,   69,   89,   89,
       60,   89,   60,   89,   64,   74,   64,   76,   89,   77,

       78,  103,   90,   89,   79,   89,   89,  105,   80,  104,
       81,   89,   91,   82,  135,   83,  106,   92,   84,   89,
      100,  101,  107,   76,  102,   77,   78,  103,   90,  136,
       79,  110,  105,   80,  104,   81,   89,   91,   82,  135,
       83,  106,   92,   84,   89,  100,  101,  107,   89,  102,
       89,  143,   93,   89,   94,  136,  110,  108,   95,   89,
       89,   89,   96,   97,  144,   98,  112,  145,   89,   89,
      113,   99,  109,  111,   89,   89,  116,  143,   93,  117,
       94,  114,  146,  108,   95,   89,  115,   96,   97,  144,
       98,  119,  112,  145,  118,  113,   99,  109,  111,  125,

      128,  137,  116,  126,  129,  117,  114,  133,  146,  120,
      138,  115,  139,  147,  121,  122,  140,  119,   89,  118,
      134,   89,   89,  141,   89,  125,  128,  137,   89,  126,
      129,  142,  148,   89,  120,  138,   89,  139,  147,  121,
      122,  140,  149,   89,  153,  150,  134,   89,   89,  141,
       89,  151,   89,  205,   89,   89,  142,  156,  148,   89,
       89,  154,  155,  158,   89,   89,   89,  152,  149,  153,
      150,  157,   89,  164,  160,  161,   89,  151,  205,  159,
      162,   89,   89,  156,   89,  174,  154,   89,  155,  158,
      167,   89,  152,  163,  165,  166,  157,   89,  164,  170,

      160,  161,   89,   89,  159,  171,  162,  175,  180,   89,
      174,  168,  169,   89,   89,  176,  167,   89,  163,  165,
      166,   89,   89,  181,  170,  179,  172,  173,  182,   89,
       89,  171,  175,  180,   89,  193,  168,  169,  177,  178,
      184,  176,  198,  183,   89,  188,   89,  186,   89,  181,
      179,  172,  173,  187,  182,  185,  189,   89,  194,  195,
      207,  193,   89,  177,  178,   89,  184,  198,  183,   89,
      188,   89,  186,  190,  191,  199,  204,  201,  187,  192,
      185,  206,  189,  194,  195,  207,  196,  197,  202,  208,
      203,  209,   89,  200,  210,  213,  211,   89,  214,  190,

      191,  199,  204,  201,  215,  192,  212,  206,  216,  217,
       89,  196,  197,  202,  208,  203,  218,  209,  200,  219,
      210,  213,  211,  214,  220,  223,  221,  224,  225,  226,
      215,  212,  227,  229,  216,  217,  222,  228,  230,  231,
      238,  218,  232,  239,  219,  236,  237,  233,  240,  220,
      241,  223,  221,  224,  225,  226,  243,  234,  227,  229,
      242,  222,  228,  244,  230,  231,  238,  232,  235,  239,
      236,  237,  245,  233,  240,  246,  241,  247,  248,   89,
      250,  243,  234,  251,  252,  253,  242,  254,  244,  255,
       89,  256,  257,  235,  249,  258,   89,  259,  245,  260,

      246,  261,  262,  247,  248,  250,  263,   89,  251,  264,
      252,  253,  265,  254,   89,  255,  256,  257,   89,  249,
       89,  258,  259,   89,   89,  260,   89,  261,  262,   89,
       89,   89,  263,   89,  264,   89,   89,  265,   57,   57,
       57,   57,   57,   61,   61,   61,   61,   61,   65,   65,
       65,   65,   65,   67,   67,   67,   67,   67,   70,   70,
       70,   70,   70,   88,   88,  130,   89,  130,  130,  130,
      132,  132,   89,  132,  132,   89,   89,   89,   89,   89,
       89,   89,   89,   89,   89,   89,  133,   89,   85,  131,
      127,  124,  123,   89,   89,   89,   87,   86,   85,   75,

       73,   72,  266,   71,   71,   66,   66,   13,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266
    } ;

static const flex_int16_t yy_chk[685] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    3,    4,    4,
        5,    5,    6,    6,    9,    9,   10,   10,   45,   43,
        3,   42,    4,   39,    5,  272,    6,   30,   46,   30,

       30,   42,   39,   41,   30,  201,  200,   45,   30,   43,
       30,   48,   39,   30,   76,   30,   46,   39,   30,  199,
       41,   41,   46,   30,   41,   30,   30,   42,   39,   77,
       30,   48,   45,   30,   43,   30,  198,   39,   30,   76,
       30,   46,   39,   30,   40,   41,   41,   46,   47,   41,
       49,   80,   40,   50,   40,   77,   48,   47,   40,  197,
      196,   51,   40,   40,   81,   40,   50,   82,  195,   52,
       50,   40,   47,   49,  194,  193,   52,   80,   40,   52,
       40,   51,   83,   47,   40,   53,   51,   40,   40,   81,
       40,   53,   50,   82,   52,   50,   40,   47,   49,   60,

       64,   78,   52,   60,   64,   52,   51,   71,   83,   53,
       78,   51,   78,   84,   53,   53,   78,   53,  192,   52,
       71,  191,   94,   79,   90,   60,   64,   78,   92,   60,
       64,   79,   90,   91,   53,   78,   95,   78,   84,   53,
       53,   78,   91,   93,   94,   92,   71,   97,   96,   79,
      190,   93,  101,  128,   98,   99,   79,   97,   90,  189,
      188,   95,   96,   99,  106,  102,  100,   93,   91,   94,
       92,   98,  187,  101,  100,  100,  104,   93,  128,   99,
      100,  186,  103,   97,  107,  106,   95,  110,   96,   99,
      103,  185,   93,  100,  102,  102,   98,  105,  101,  104,

      100,  100,  109,  184,   99,  105,  100,  107,  110,  108,
      106,  103,  103,  120,  183,  108,  103,  111,  100,  102,
      102,  115,  112,  111,  104,  109,  105,  105,  112,  118,
      114,  105,  107,  110,  113,  118,  103,  103,  108,  108,
      113,  108,  120,  112,  182,  115,  181,  114,  116,  111,
      109,  105,  105,  114,  112,  113,  116,  119,  118,  118,
      134,  118,  180,  108,  108,  117,  113,  120,  112,  121,
      115,  122,  114,  117,  117,  121,  126,  122,  114,  117,
      113,  129,  116,  118,  118,  134,  119,  119,  125,  135,
      125,  136,  179,  121,  137,  139,  138,  178,  140,  117,

      117,  121,  126,  122,  142,  117,  138,  129,  143,  144,
      177,  119,  119,  125,  135,  125,  145,  136,  121,  146,
      137,  139,  138,  140,  147,  203,  202,  205,  207,  208,
      142,  138,  209,  211,  143,  144,  202,  210,  212,  213,
      220,  145,  214,  221,  146,  216,  219,  215,  222,  147,
      223,  203,  202,  205,  207,  208,  225,  215,  209,  211,
      224,  202,  210,  227,  212,  213,  220,  214,  215,  221,
      216,  219,  231,  215,  222,  232,  223,  233,  234,  176,
      235,  225,  215,  236,  241,  242,  224,  243,  227,  244,
      175,  247,  248,  215,  234,  249,  174,  250,  231,  254,

      232,  255,  258,  233,  234,  235,  259,  173,  236,  260,
      241,  242,  264,  243,  172,  244,  247,  248,  171,  234,
      170,  249,  250,  169,  168,  254,  167,  255,  258,  166,
      165,  164,  259,  163,  260,  162,  161,  264,  267,  267,
      267,  267,  267,  268,  268,  268,  268,  268,  269,  269,
      269,  269,  269,  270,  270,  270,  270,  270,  271,  271,
      271,  271,  271,  273,  273,  274,  160,  274,  274,  274,
      275,  275,  159,  275,  275,  158,  157,  156,  155,  154,
      153,  152,  151,  150,  149,  148,  133,   88,   85,   69,
       63,   59,   56,   55,   54,   44,   38,   36,   32,   23,

       18,   17,   13,   12,   11,    8,    7,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "asm.yy"
/*
 * Copyright (c) 2002 - 2005 Magnus Lind.
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 *   1. The origin of this software must not be misrepresented; you must not
 *   claim that you wrote the original software. If you use this software in a
 *   product, an acknowledgment in the product documentation would be
 *   appreciated but is not required.
 *
 *   2. Altered source versions must be plainly marked as such, and must not
 *   be misrepresented as being the original software.
 *
 *   3. This notice may not be removed or altered from any distribution.
 *
 */
/* scanner for a simple assembler */
#line 30 "asm.yy"
#include <stdio.h>
#include <string.h>
#include "int.h"
#include "buf.h"
#include "parse.h"
#include "asm.tab.h"

#define YY_EXIT_FAILURE 1
#define MAX_SRC_BUFFER_DEPTH 10
static YY_BUFFER_STATE src_buffers[MAX_SRC_BUFFER_DEPTH];
static int src_buffer_depth = 0;

static char *strdupped_get(char *text);
static int strdupped_cmp(const void *a, const void *b);
static void strdupped_free(void *a);

int num_lines = 1;
int push_state_skip = 0;
int push_state_init = 0;
int push_state_macro = 0;
struct vec strdupped[1];

#line 734 "lex.yy.c"

#line 736 "lex.yy.c"

#define INITIAL 0
#define SKIP 1
#define SKIP_ALL 2
#define QUOTED_STRING 3
#define SKIP_LINE 4
#define MACROO 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
    static int yy_top_state ( void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 60 "asm.yy"


#line 63 "asm.yy"
	if(push_state_init)
	{push_state_init = 0; yy_push_state(INITIAL); }
	if(push_state_skip)
	{push_state_skip = 0; yy_push_state(SKIP); }
	if(push_state_macro)
	{push_state_macro = 0; yy_push_state(MACROO); }

#line 979 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 267 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 266 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 70 "asm.yy"
return IF;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 71 "asm.yy"
BEGIN(SKIP_ALL);
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 72 "asm.yy"
BEGIN(SKIP);
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 73 "asm.yy"
yy_pop_state();
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 75 "asm.yy"
return INCLUDE;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 76 "asm.yy"
return MACRO;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 78 "asm.yy"
return DEFINED;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 79 "asm.yy"
return ORG;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 80 "asm.yy"
return ERROR;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 81 "asm.yy"
return ECHO1;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 82 "asm.yy"
return INCBIN;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 83 "asm.yy"
return INCLEN;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 84 "asm.yy"
return INCWORD;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 85 "asm.yy"
return RES;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 86 "asm.yy"
return WORD;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 87 "asm.yy"
return BYTE;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 88 "asm.yy"
return TEXT;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 90 "asm.yy"
BEGIN(QUOTED_STRING);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 91 "asm.yy"
BEGIN(SKIP_LINE);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 93 "asm.yy"
return LDA;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 94 "asm.yy"
return LDX;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 95 "asm.yy"
return LDY;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 96 "asm.yy"
return STA;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 97 "asm.yy"
return STX;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 98 "asm.yy"
return STY;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 99 "asm.yy"
return AND;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 100 "asm.yy"
return ORA;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 101 "asm.yy"
return EOR;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 102 "asm.yy"
return ADC;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 103 "asm.yy"
return SBC;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 104 "asm.yy"
return CMP;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 105 "asm.yy"
return CPX;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 106 "asm.yy"
return CPY;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 108 "asm.yy"
return TSX;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 109 "asm.yy"
return TXS;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 110 "asm.yy"
return PHA;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 111 "asm.yy"
return PLA;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 112 "asm.yy"
return PHP;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 113 "asm.yy"
return PLP;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 114 "asm.yy"
return SEI;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 115 "asm.yy"
return CLI;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 116 "asm.yy"
return NOP;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 117 "asm.yy"
return TYA;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 118 "asm.yy"
return TAY;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 119 "asm.yy"
return TXA;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 120 "asm.yy"
return TAX;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 121 "asm.yy"
return CLC;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 122 "asm.yy"
return SEC;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 123 "asm.yy"
return RTS;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 124 "asm.yy"
return CLV;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 125 "asm.yy"
return CLD;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 126 "asm.yy"
return SED;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 128 "asm.yy"
return JSR;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 129 "asm.yy"
return JMP;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "asm.yy"
return BEQ;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 131 "asm.yy"
return BNE;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 132 "asm.yy"
return BCC;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "asm.yy"
return BCS;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "asm.yy"
return BPL;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 135 "asm.yy"
return BMI;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 136 "asm.yy"
return BVC;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 137 "asm.yy"
return BVS;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 138 "asm.yy"
return INX;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 139 "asm.yy"
return DEX;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 140 "asm.yy"
return INY;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 141 "asm.yy"
return DEY;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 142 "asm.yy"
return INC;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 143 "asm.yy"
return DEC;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 144 "asm.yy"
return LSR;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "asm.yy"
return ASL;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "asm.yy"
return ROR;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "asm.yy"
return ROL;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "asm.yy"
return BIT;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 150 "asm.yy"
{ yylval.num = atoi(yytext); return NUMBER; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 152 "asm.yy"
{ yylval.num = strtol(yytext + 1, NULL, 16); return NUMBER; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 154 "asm.yy"
return LT;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 155 "asm.yy"
return GT;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 156 "asm.yy"
return EQ;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 157 "asm.yy"
return NEQ;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 158 "asm.yy"
return LNOT;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 159 "asm.yy"
return LAND;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 160 "asm.yy"
return LOR;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 162 "asm.yy"
return LPAREN;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 163 "asm.yy"
return RPAREN;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 164 "asm.yy"
return COMMA;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 165 "asm.yy"
return COLON;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 166 "asm.yy"
return HASH;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 167 "asm.yy"
return PLUS;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 168 "asm.yy"
return MINUS;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 169 "asm.yy"
return MULT;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 170 "asm.yy"
return DIV;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 171 "asm.yy"
return MOD;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 173 "asm.yy"
return ASSIGN;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 174 "asm.yy"
return GUESS;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 176 "asm.yy"
return X;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 177 "asm.yy"
return Y;
	YY_BREAK
case 97:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 179 "asm.yy"
{ yylval.str = strdupped_get(yytext); return LABEL; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 180 "asm.yy"
{ yylval.str = strdupped_get(yytext); return SYMBOL; }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 182 "asm.yy"
++num_lines;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 184 "asm.yy"
/* eat whitespace */
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 186 "asm.yy"
printf("unknown character found %s\n", yytext);
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 188 "asm.yy"
yy_push_state(SKIP_ALL);
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 189 "asm.yy"
{ yy_pop_state(); return IF; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 190 "asm.yy"
BEGIN(INITIAL);
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 191 "asm.yy"
yy_pop_state();
	YY_BREAK
case 106:
/* rule 106 can match eol */
YY_RULE_SETUP
#line 192 "asm.yy"
++num_lines;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 193 "asm.yy"

	YY_BREAK
case 108:
YY_RULE_SETUP
#line 195 "asm.yy"
yy_pop_state();
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 196 "asm.yy"
{ yylval.str = yytext; return MACRO_STRING; }
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 197 "asm.yy"
{ yylval.str = yytext; return MACRO_STRING; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 199 "asm.yy"
yy_push_state(SKIP_ALL);
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 200 "asm.yy"
yy_pop_state();
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 201 "asm.yy"
++num_lines;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 202 "asm.yy"

	YY_BREAK
case 115:
/* rule 115 can match eol */
YY_RULE_SETUP
#line 204 "asm.yy"
{
    /* multi-line string with correct line count */
    char *p = strdupped_get(yytext);
    yylval.str = p;
    while (*p != '\0')
    {
        if (*p++ == '\n')
        {
            ++num_lines;
        }
    }
    return STRING;
}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 217 "asm.yy"
BEGIN(INITIAL);
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
#line 219 "asm.yy"
{ ++num_lines; BEGIN(INITIAL); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 220 "asm.yy"

	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(SKIP):
case YY_STATE_EOF(SKIP_ALL):
case YY_STATE_EOF(QUOTED_STRING):
case YY_STATE_EOF(SKIP_LINE):
case YY_STATE_EOF(MACROO):
#line 222 "asm.yy"
{
	    if(--src_buffer_depth == 0)
	    {
		yyterminate();
	    }
	    else
	    {
		yy_delete_buffer(YY_CURRENT_BUFFER);
		yy_switch_to_buffer(src_buffers[src_buffer_depth]);
	    }
	}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 234 "asm.yy"
ECHO;
	YY_BREAK
#line 1667 "lex.yy.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 267 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 267 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 266);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 234 "asm.yy"


void scanner_init(void)
{
    vec_init(strdupped, sizeof(char*));
}

void asm_src_buffer_push(struct buf *buffer)
{
    if(src_buffer_depth == MAX_SRC_BUFFER_DEPTH)
    {
	fprintf(stderr, "source buffers nested too deep\n");
	exit(1);
    }
    src_buffers[src_buffer_depth++] = YY_CURRENT_BUFFER;
    yy_scan_bytes(buf_data(buffer), buf_size(buffer));
}

static char *strdupped_get(char *text)
{
    char **pp;
    /*printf("get \"%s\" => ", text);*/
    if(vec_insert_uniq(strdupped, strdupped_cmp, &text, (void*)&pp))
    {
        /* replace the pointer to <text> since <text> will be reused */
        *pp = strdup(text);
    }
    /*printf("%p\n", *pp);*/
    return *pp;
}

static void strdupped_free(void *a)
{
    char *b = *(char**)a;
    /*printf("free => %p \"%s\"\n", b, b);*/
    free(b);
}

static int strdupped_cmp(const void *a, const void *b)
{
    char *c = *(char**)a;
    char *d = *(char**)b;

    return strcmp(c, d);
}

void scanner_free(void)
{
    vec_free(strdupped, strdupped_free);
}


void silence_warnings_about_unused_functions(void)
{
    yyunput(0, NULL);
    input();
    yy_top_state();
}

